@@ -49,6 +49,13 @@ def _has_stable_branches():
     return False
 
 
+def _ref_sort_key(ref):
+    # note(frickler): make sure to sort series like 2023.1 after zed
+    if ref.startswith("2"):
+        return "zzz" + ref
+    return ref
+
+
 def _get_other_versions(app):
     if not app.config.html_theme_options.get('show_other_versions', False):
         return []
@@ -62,22 +69,24 @@ def _get_other_versions(app):
     refs = repo.get_refs()
     for ref in refs.keys():
         ref = ref.decode('utf-8')
-        if ref.startswith('refs/remotes/origin/stable'):
+        if (ref.startswith('refs/remotes/origin/stable') or
+           ref.startswith('refs/remotes/origin/unmaintained')):
             series = ref.rpartition('/')[-1]
             all_series.append(series)
         elif ref.startswith('refs/tags/') and ref.endswith('-eol'):
             series = ref.rpartition('/')[-1][:-4]
             all_series.append(series)
-    all_series.sort()
+    all_series = list(set(all_series))
+    all_series.sort(key=_ref_sort_key)
 
-    # NOTE(dhellmann): Given when this feature was implemented, we
-    # assume that the earliest version we can link to is for
-    # mitaka. Projects that have older docs online can set the option
+    # NOTE(frickler): Since older versions are now unmaintained,
+    # assume that the earliest version we want to link to is for
+    # zed. Projects that have older docs online can set the option
     # to indicate another start point. Projects that come later should
     # automatically include everything they actually have available
     # because the start point is not present in the list.
     earliest_desired = app.config.html_theme_options.get(
-        'earliest_published_series', 'mitaka')
+        'earliest_published_series', 'zed')
     if earliest_desired and earliest_desired in all_series:
         interesting_series = all_series[all_series.index(earliest_desired):]
     else:
